# -*- coding: utf8 -*-
from django.conf.urls import patterns

urlpatterns = patterns('')
